[−][src]Struct embedded_text::alignment::justified::JustifiedSpaceConfig
Internal state information used to store width of whitespace characters when rendering fully justified text.
The fully justified renderer works by calculating the width of whitespace characters for the current line. Due to integer arithmetic, there can be remainder pixels when a single space width is used. This struct stores two width values so the whole line will always (at least if there's a space in the line) take up all available space.