[−][src]Trait embedded_text::alignment::HorizontalTextAlignment
Horizontal text alignment base trait.
Use implementors to parametrize TextBoxStyle and TextBoxStyleBuilder.
Associated Constants
pub const STARTING_SPACES: bool[src]
Whether or not render spaces in the start of the line.
pub const ENDING_SPACES: bool[src]
Whether or not render spaces in the end of the line.